#!/usr/bin/php
<?php

 mysql_connect("localhost","root","LetsTry08") or die ('nix connect');
 mysql_select_db("20000euro");

 $sql = "select id, email from email_log;";

 $ergebnis = mysql_query($sql) or die('error: ' . $sql);
 $fhandle = fopen ("./exportdirectoryemails/leads.txt", "w");
 while($row = mysql_fetch_row($ergebnis)){
  $line = $row[0] . "," . $row[1] . "\n";
  fwrite ($fhandle, $line);
 }

fclose ($fhandle);

?>
